@@ -60,14 +60,21 @@ class Coordinator:
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        self.stop()
+
+    def stop(self, delay=None):
         # shouldn't be any procs left, but just in case
         for proc in self._processes:
             if proc:
                 try:
-                    proc.join(5)
-                except Exception as e:
+                    if delay is not None:
+                        proc.join(delay)
+                except Exception:
+                    pass
+                try:
+                    proc.terminate()
+                except Exception:
                     pass
-                proc.terminate()
 
     @staticmethod
     def _write_sep(s, txt):
@@ -155,7 +162,7 @@ class Coordinator:
                     for kind, data in items:
                         self._process_worker_message(session, kind, data)
                 available_qs = [q._reader for q in self._result_qs if q is not None]
-                (inputs, _, _) = select.select(available_qs, [], [], 0)
+                (inputs, _, _) = select.select(available_qs, [], [], timeout)
 
         #while any(self._result_qs):
         for test in self._tests:
@@ -165,15 +172,13 @@ class Coordinator:
             # Function objects in pytest are not pickle-able, so have to send string nodeid and
             # do lookup on worker side
             item = [t.nodeid for t in test] if isinstance(test, list) else test.nodeid
-            try:
-                self._test_q.put(item, timeout=1)
-            except Queue.Full:
-                pass
+            self._test_q.put(item)
 
+        read_results()
         for _ in self._processes:
             self._test_q.put(None)  # signals end
 
-        while any(self._result_qs):
+        while any([q is not None for q in self._result_qs]):
             read_results(timeout=1)
         self._test_q.close()
         sys.stdout.write("\r\n")
