@@ -111,20 +111,25 @@ def pytest_runtestloop(session):
                         if [a for a in args if a in item._fixtureinfo.argnames]:
                             func()
                             break
-            except Exception:
-                print(f">>>> ERROR in global initializer {func.name}. Aborting!")
-                sys.exit(1)
+            except Exception as e:
+                print(">>>> ERROR in global initializer. Aborting! <<<<<\n %s" % str(e))
+                if hasattr(session.config, 'coordinator'):
+                    session.config.coordinator.stop(None)
+                raise
     if getattr(session.config.option, "numcores", None) is None or is_degraded() or getattr(session.config.option, "mproc_disabled"):
         return  # return of None indicates other hook impls will be executed to do the task at hand
     if not session.config.getvalue("collectonly") and worker is None:
-        # main coordinator loop:
-        with session.config.coordinator as coordinator:
-            coordinator.set_items(session.items)
-            try:
-                coordinator.run(session)
-            except Exception as e:
-                print(">>> ERROR in run loop;  unexpected Exception\n %s" % str(e))
-                raise
+        try:
+            # main coordinator loop:
+            with session.config.coordinator as coordinator:
+                coordinator.set_items(session.items)
+                try:
+                    coordinator.run(session)
+                except Exception as e:
+                    print(">>> ERROR in run loop;  unexpected Exception\n %s" % str(e))
+                    raise
+        finally:
+            session.config.coordinator.stop(None)
     else:
         worker.test_loop(session)
     return True
