@@ -1,12 +1,7 @@
-try:
-    import pydev
-    _degraded = True  # cannot run multiproc under pydev
-except:
-    _degraded = False
-
+import os
 
 def is_degraded():
-    return _degraded
+    return os.environ.get("PYTEST_MPROC_DISABLED")
 
 
 class _GlobalFixtures:
